@@ -89,11 +89,21 @@ class PriceMarkerAdmin(admin.ModelAdmin):
     search_fields = ['ipn__code']
 
 
+class ProductAdmin(admin.ModelAdmin):
+    """Custom admin for the ``Product`` model."""
+    list_display = ('product_number', )
+
+
 class ShapeAdmin(admin.ModelAdmin):
     list_display = ['code', 'name']
     search_fields = ['code', 'name']
 
 
+class TechnologyAdmin(admin.ModelAdmin):
+    """Custom admin for the ``Technology`` model."""
+    list_display = ('identifier', )
+
+
 class UnitAdmin(admin.ModelAdmin):
     list_display = ['code', 'description']
     search_fields = ['code', 'description']
@@ -110,5 +120,7 @@ admin.site.register(models.EPN, EPNAdmin)
 admin.site.register(models.IPN, IPNAdmin)
 admin.site.register(models.PriceGroup, PriceGroupAdmin)
 admin.site.register(models.PriceMarker, PriceMarkerAdmin)
+admin.site.register(models.Product, ProductAdmin)
 admin.site.register(models.Shape, ShapeAdmin)
+admin.site.register(models.Technology, TechnologyAdmin)
 admin.site.register(models.Unit, UnitAdmin)
